@@ -1,6 +1,7 @@
 from typing import Dict, List
 from enum import Enum
 from dataclasses import dataclass, field
+from string import Template
 from datetime import datetime
 import inflect
 from pygqlc import GraphQLClient
@@ -47,6 +48,26 @@ query {
 '''
 
 
+class BadQueryBuild(Exception):
+    """This exception raises when the query returns with an error code 400. 
+      It may have an GQL sintax error or an invalid child.
+    """
+    pass
+
+
+class InternalServerError(Exception):
+    """This exception raises when the query returns with an error code 500. 
+      It may have some server issue.
+    """
+    pass
+
+
+class QueryFailed(Exception):
+    """This exception triggers all possible query errors.
+    """
+    pass
+
+
 @dataclass
 class QueryBuilder():
     _kind: BaseGraphQLType = None
@@ -133,20 +154,15 @@ class QueryBuilder():
         """
         _query = self.compile()
         data, errors = self._gql.query(_query)
+        if errors:
+            self._raising_errors(errors)
+            return None
         if self._type == QueryType.SINGULAR:
-            if errors:
-                instance = self._kind()
-                instance.__errors__ = errors
-                return instance
             instance = self._kind(**data)
             instance.__sync__ = True
             return instance
         else:
             # QueryType.PLURAL
-            if errors:
-                instances = [self._kind()]
-                instances[0].__errors__ = errors
-                return instances
             instances = [self._kind(**datum) for datum in data]
             # mark as synced (AKA: data ok)
             for i, instance in enumerate(instances):
@@ -268,6 +284,30 @@ class QueryBuilder():
         if type(v) == str:
             # regular case, this means it's a string, include double quotes
             return f'{k}: "{v}"'
+        if type(v) == list:
+            # To know how to return the values inside of the list, we've to know
+            # the type of the elements inside. Take one element and check which type is.
+            single_item = v[-1]
+            if isinstance(single_item, (int, float)):
+                # Don't do anything. Return this as normal as it'll work
+                return f'{k}: {v}'
+            # If it's not int or float, need to do a conversion to obtain a correct type for
+            # the query. If the item type is str, then it can pass, but if it's datetime or
+            # bool, convert the values of the list first before pass to the next part
+            if isinstance(single_item, bool):
+                v = [["false", "true"][item] for item in v]
+            if isinstance(single_item, datetime):
+                v = [get_iso8601_str(get_utc_date(item)) for item in v]
+            # Convert the list to a single and large string to pass it to the query.
+            # Create the template to fill the values
+            string_values = Template('"$value"')
+            items = '['  # Initialize the string
+            for item in v:
+                items += string_values.substitute(value=item)+','
+            # Erase the last comma and close the brackets
+            items = items[:-1]+']'
+            # return the string with all the items together
+            return f'{k}: {items}'
         if type(v) == bool:
             return f'{k}: {["false","true"][v]}'  # short-hand for inline if
         if type(v) == datetime:
@@ -339,3 +379,23 @@ class QueryBuilder():
     # delete
     # nested
     # apply
+
+    def _raising_errors(self, errors):
+        """This function raises any error when is getting the data from a query.
+
+        Args:
+            errors (list): list with all errors.
+
+        Raises:
+            BadQueryBuild
+            InternalServerError
+            QueryFailed
+        """
+        for error in errors:
+            message = error['message'].split('\n')[0]
+            if 'returning code of 400.' in message:
+                raise BadQueryBuild(message)
+            elif 'returning code of 500.' in message:
+                raise InternalServerError(message)
+            else:
+                raise QueryFailed(message)
