@@ -1,4 +1,5 @@
 one_to_one_map = {
+    "ID": ("Union[str, int]", "0"),
     "String": ("str", "''"),
     "Int": ("int", "0"),
     "Float": ("float", "0.0"),
@@ -7,17 +8,50 @@ one_to_one_map = {
     "DateTime": ("datetime", "datetime.now()"),
     "Boolean": ("bool", "False"),
     "map": ("dict", "{}"),
+    "Json": ("dict", "{}"),
+    "Jsonb": ("dict", "{}"),
     "Text": ("str", "''"),
     "Enum": ("str", "''")
 }
 
+
+def default_map(var_type, variable):
+    """This function determines the 'python values'
+
+    Args:
+        var_type (str): Attribut type
+        variable (str): Default value
+
+    Returns:
+        tuple: returns a tuple with the class data
+    """
+    if var_type == 'Int':
+        return ("int", int(variable))
+    elif var_type == 'Float':
+        return ("float", float(variable))
+    elif var_type == 'Date':
+        return ('date', f'get_datetime_object({variable}, "{var_type}")')
+    elif var_type == 'Time':
+        return ('time', f'get_datetime_object({variable}, "{var_type}")')
+    elif var_type == 'DateTime':
+        return ('datetime', f'get_datetime_object({variable}, "{var_type}")')
+    elif var_type == "Boolean":
+        return ("bool", variable.capitalize())
+    elif var_type == "map":
+        return ("dict", variable)
+    elif var_type == "String":
+        return ("str", variable)
+    else:  # Enum
+        return (var_type, variable)
+
+
 imports = """
 from __future__ import annotations
 from typing import List, Union
 from datetime import datetime, date, time
 from gstorm.GraphQLType import GraphQLType
 from gstorm.helpers.typing_helpers import convert_to, list_convert_to, gql_repr, gql_list_repr
-from gstorm.helpers.date_helpers import iso8601_to_local_date
+from gstorm.helpers.date_helpers import iso8601_to_local_date, get_datetime_object
 import attr
 from enum import Enum
 """
