@@ -15,7 +15,7 @@ def remove_capital(word):
 
 
 def contains_digits(d):
-    _digits = re.compile('\d')
+    _digits = re.compile(r'\d')
     return bool(_digits.search(d))
 
 
